<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:output method="xml" indent="yes" doctype-system="DTD/patent-apply-evaluation-form.dtd" encoding="UTF-8"/>
  <xsl:template match="/patent-apply-evaluation-form">
    <patent-apply-evaluation-form receive-num="" receive-date="" dtd-version="2.0.1" application-version="1.0.7" form-version="1.0.6" fee-version="1.0.2" application-num="" status="a" produced-by="applicant" form-type="n">
      <xsl:attribute name="application-num">
        <xsl:value-of select="application-num"/>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="type-of-patent='發明'">
          <xsl:attribute name="type-of-patent">invention</xsl:attribute>
        </xsl:when>
        <xsl:when test="type-of-patent='新型'">
          <xsl:attribute name="type-of-patent">utility</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="type-of-patent">design</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:choose>
        <xsl:when test="count(recognizance3)&gt;0">
          <xsl:attribute name="recognizance3">
            <xsl:text>y</xsl:text>
          </xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="recognizance3">
            <xsl:text>n</xsl:text>
          </xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:choose>
        <xsl:when test="count(recognizance4)&gt;0">
          <xsl:attribute name="recognizance4">
            <xsl:text>y</xsl:text>
          </xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="recognizance4">
            <xsl:text>n</xsl:text>
          </xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:choose>
        <xsl:when test="count(recognizance5)&gt;0">
          <xsl:attribute name="recognizance5">
            <xsl:text>y</xsl:text>
          </xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="recognizance5">
            <xsl:text>n</xsl:text>
          </xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:choose>
        <xsl:when test="count(recognizance6)&gt;0">
          <xsl:attribute name="recognizance6">
            <xsl:text>y</xsl:text>
          </xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="recognizance6">
            <xsl:text>n</xsl:text>
          </xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:choose>
        <xsl:when test="check-list/contact='外審無須附送'">
          <xsl:attribute name="with-contact">
            <xsl:text>n</xsl:text>
          </xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="with-contact">
            <xsl:text>y</xsl:text>
          </xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="basis"/>
      <xsl:copy-of select="case-code"/>
      <file-reference-id>
        <xsl:value-of select="file-reference-id"/>
      </file-reference-id>
      <exam-result>
        <xsl:value-of select="exam-result"/>
      </exam-result>
      <xsl:apply-templates select="patent-title-tw"/>

      <xsl:apply-templates select="parties"/>

      <check-list>
        <xsl:apply-templates select="check-list"/>
      </check-list>
	  
    </patent-apply-evaluation-form>
  </xsl:template>

  <xsl:template match="parties">
    <parties>
      <applicants>
        <xsl:choose>
          <xsl:when test="//contact='外審無須附送'">
            <xsl:apply-templates select="//simpleapplicant"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:apply-templates select="applicant"/>
          </xsl:otherwise>
        </xsl:choose>
      </applicants>
    </parties>
  </xsl:template>
  
  <xsl:template match="applicant">
    <applicant>
      <xsl:attribute name="sequence">
        <xsl:number value="position()" format="1"/>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="ap-designated-receiver='是'">
          <xsl:attribute name="designated-receiver">
            <xsl:value-of  select="translate(ap-designated-receiver,'是','y')"/>
          </xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="designated-receiver">
            <xsl:text>n</xsl:text>
          </xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <addressbook lang="tw">
        <xsl:choose>
          <xsl:when test="ap-name-type='自然人'">
            <last-name>
              <xsl:value-of select="normalize-space(substring-before(ap-tw-name,','))"/>
            </last-name>
            <first-name>
              <xsl:value-of select="normalize-space(substring-after(ap-tw-name,','))"/>
            </first-name>
          </xsl:when>
          <xsl:otherwise>
            <orgname>
              <xsl:value-of select="normalize-space(ap-tw-comname)"/>
            </orgname>
          </xsl:otherwise>
        </xsl:choose>
        <role>
          <xsl:value-of select="ap-name-type"/>
        </role>
        <iid>
          <xsl:value-of select="ap-tw-iid"/>
        </iid>
        <registered-number/>
        <representative>
          <xsl:value-of select="ap-tw-representative"/>
        </representative>
        <address lang="tw">
          <zip-code>
            <xsl:value-of select="ap-zip-code"/>
          </zip-code>
          <dtext>
            <xsl:value-of select="ap-tw-address"/>
          </dtext>
        </address>
        <phones>
          <phone-region/>
          <phone>
            <xsl:value-of select="ap-tw-phone"/>
          </phone>
        </phones>
        <fax>
          <xsl:value-of select="ap-tw-fax"/>
        </fax>
        <cell-phone>
          <xsl:value-of select="ap-tw-cell-phone"/>
        </cell-phone>
        <email>
          <xsl:value-of select="ap-tw-email"/>
        </email>
      </addressbook>
      <addressbook lang="en">
        <xsl:choose>
          <xsl:when test="ap-name-type='自然人'">
            <last-name>
              <xsl:value-of select="normalize-space(substring-before(ap-en-name,','))"/>
            </last-name>
            <first-name>
              <xsl:value-of select="normalize-space(substring-after(ap-en-name,','))"/>
            </first-name>
          </xsl:when>
          <xsl:otherwise>
            <orgname>
              <xsl:value-of select="normalize-space(ap-en-comname)"/>
            </orgname>
          </xsl:otherwise>
        </xsl:choose>
        <iid>
          <xsl:value-of select="ap-tw-iid"/>
        </iid>
        <registered-number/>
        <representative>
          <xsl:value-of select="ap-en-representative"/>
        </representative>
        <address lang="en">
          <dtext>
            <xsl:value-of select="ap-en-address"/>
          </dtext>
        </address>
        <email/>
      </addressbook>
      <nationality>
        <country>
          <xsl:value-of select="substring(ap-country,'3')"/>
        </country>
        <country-code>
          <xsl:value-of select="substring(ap-country,'1','2')"/>
        </country-code>
      </nationality>
      <residence>
        <country>
          <xsl:value-of select="ap-living-country"/>
        </country>
      </residence>
      <legal-representative lang="tw">
        <addressbook lang="tw">
          <last-name>
            <xsl:value-of select="normalize-space(substring-before(ap-tw-legal-name,','))"/>
          </last-name>
          <first-name>
            <xsl:value-of select="normalize-space(substring-after(ap-tw-legal-name,','))"/>
          </first-name>
          <iid>
            <xsl:value-of select="ap-tw-legal-iid"/>
          </iid>
          <registered-number />
          <address lang="tw">
            <dtext />
          </address>
          <email />
        </addressbook>
      </legal-representative>
    </applicant>
  </xsl:template>

  <xsl:template match="simpleapplicant">
    <applicant>
      <xsl:attribute name="sequence">
        <xsl:number value="position()" format="1"/>
      </xsl:attribute>
      <xsl:attribute name="designated-receiver">
        <xsl:text>n</xsl:text>
      </xsl:attribute>
      <addressbook lang="tw">
        <xsl:choose>
          <xsl:when test="count(simpleap-tw-name)&gt;0">
            <last-name>
              <xsl:value-of select="normalize-space(substring-before(simpleap-tw-name,','))"/>
            </last-name>
            <first-name>
              <xsl:value-of select="normalize-space(substring-after(simpleap-tw-name,','))"/>
            </first-name>
          </xsl:when>
          <xsl:otherwise>
            <orgname>
              <xsl:value-of select="normalize-space(simpleap-tw-comname)"/>
            </orgname>
          </xsl:otherwise>
        </xsl:choose>
        <role/>
        <iid/>
        <registered-number />
        <representative />
        <address lang="tw">
          <zip-code/>
          <dtext />
        </address>
        <phones>
          <phone-region />
          <phone />
        </phones>
        <fax />
        <cell-phone />
        <email />
      </addressbook>
      <addressbook lang="en">
        <xsl:choose>
          <xsl:when test="count(simpleap-en-name)&gt;0">
            <last-name>
              <xsl:value-of select="normalize-space(substring-before(simpleap-en-name,','))"/>
            </last-name>
            <first-name>
              <xsl:value-of select="normalize-space(substring-after(simpleap-en-name,','))"/>
            </first-name>
          </xsl:when>
          <xsl:otherwise>
            <orgname>
              <xsl:value-of select="normalize-space(simpleap-en-comname)"/>
            </orgname>
          </xsl:otherwise>
        </xsl:choose>
        <iid/>
        <registered-number />
        <representative />
        <address lang="en">
          <dtext />
        </address>
        <email />
      </addressbook>
      <nationality>
        <country>
          <xsl:value-of select="substring(simpleap-country,'3')"/>
        </country>
        <country-code>
          <xsl:value-of select="substring(simpleap-country,'1','2')"/>
        </country-code>
      </nationality>
      <residence>
        <country />
      </residence>
      <legal-representative lang="tw">
        <addressbook lang="tw">
          <last-name />
          <first-name />
          <iid />
          <registered-number />
          <address lang="tw">
            <dtext />
          </address>
          <email />
        </addressbook>
      </legal-representative>
    </applicant>
  </xsl:template>

  <xsl:template match="agent">
    <agent agent-type="agent" rep-type="agent">
      <xsl:attribute name="sequence">
        <xsl:number value="position()" format="1"/>
      </xsl:attribute>
      <addressbook lang="tw">
        <last-name>
          <xsl:value-of select="normalize-space(substring-before(ag-tw-name,','))"/>
        </last-name>
        <first-name>
          <xsl:value-of select="normalize-space(substring-after(ag-tw-name,','))"/>
        </first-name>
        <iid>
          <xsl:value-of select="ag-tw-iid"/>
        </iid>
        <registered-number/>
        <address lang="tw">
          <zip-code>
            <xsl:value-of select="ag-zip-code"/>
          </zip-code>
          <dtext>
            <xsl:value-of select="ag-tw-address"/>
          </dtext>
        </address>
        <phones>
          <phone-region/>
          <phone>
            <xsl:value-of select="ag-tw-phone"/>
          </phone>
        </phones>
        <fax>
          <xsl:value-of select="ag-tw-fax"/>
        </fax>
        <cell-phone>
          <xsl:value-of select="ag-tw-cell-phone"/>
        </cell-phone>
        <email>
          <xsl:value-of select="ag-tw-email"/>
        </email>
      </addressbook>
      <customer-number>
        <xsl:value-of select="ag-customer-number"/>
      </customer-number>
    </agent>
  </xsl:template>

  <xsl:template match="simpleagent">
    <agent agent-type="agent" rep-type="agent">
      <xsl:attribute name="sequence">
        <xsl:number value="position()" format="1"/>
      </xsl:attribute>
      <addressbook lang="tw">
        <last-name>
          <xsl:value-of select="normalize-space(substring-before(simpleag-tw-name,','))"/>
        </last-name>
        <first-name>
          <xsl:value-of select="normalize-space(substring-after(simpleag-tw-name,','))"/>
        </first-name>
        <iid/>
        <registered-number/>
        <address lang="tw">
          <zip-code/>
          <dtext/>
        </address>
        <phones>
          <phone-region/>
          <phone/>
        </phones>
        <fax/>
        <cell-phone/>
        <email/>
      </addressbook>
      <customer-number/>
    </agent>
  </xsl:template>

  <xsl:template match="basis">
    <basis>
      <date>
        <xsl:value-of select="basis-date"/>
      </date>
      <basis1></basis1>
      <basis2>
        <xsl:value-of select="basis-basis2"/>
      </basis2>
      <basis-num>
        <xsl:value-of select="basis-num"/>
      </basis-num>
    </basis>
  </xsl:template>


  <xsl:attribute-set name="AddPageCount">
    <xsl:attribute name="add">y</xsl:attribute>
    <xsl:attribute name="page-count"/>
  </xsl:attribute-set>

  <xsl:attribute-set name="Add">
    <xsl:attribute name="add">y</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="AddLang">
    <xsl:attribute name="add">y</xsl:attribute>
    <xsl:attribute name="lang"/>
  </xsl:attribute-set>

  <xsl:template match="contact| 
				search-report| 
				search-history-file| 
				ipo-file|
        reference-file">
    <xsl:copy use-attribute-sets="Add">
      <xsl:attribute name="list-seq">
        <xsl:value-of select="@list-seq"/>
      </xsl:attribute>
      <xsl:apply-templates select="*|node()"/>
    </xsl:copy>
  </xsl:template>

  <xsl:template match="check-list">
    <xsl:apply-templates select="contact[string-length(string())&gt;'0']"/>
    <xsl:apply-templates select="search-report[string-length(string())&gt;'0']"/>
    <xsl:apply-templates select="search-history-file[string-length(string())&gt;'0']"/>
    <xsl:apply-templates select="ipo-file[string-length(string())&gt;'0']"/>
    <xsl:apply-templates select="reference-file[string-length(string())&gt;'0']"/>
  </xsl:template>


  <xsl:template match="i">
    <i>
      <xsl:apply-templates select="*|text()"/>
    </i>
  </xsl:template>
  <xsl:template match="u">
    <u>
      <xsl:apply-templates select="*|text()"/>
    </u>
  </xsl:template>
  <xsl:template match="b">
    <b>
      <xsl:apply-templates select="*|text()"/>
    </b>
  </xsl:template>
  <xsl:template match="s">
    <s>
      <xsl:apply-templates select="*|text()"/>
    </s>
  </xsl:template>
  <xsl:template match="sup">
    <sup>
      <xsl:apply-templates select="*|text()"/>
    </sup>
  </xsl:template>
  <xsl:template match="sub">
    <sub>
      <xsl:apply-templates select="*|text()"/>
    </sub>
  </xsl:template>


</xsl:stylesheet>
